;; Generated package description from .el  -*- boxyno-byte-compile: t -*-
(define-package "boxy" "2.0.0.0.20250325.150735" "A boxy layout framework" '((emacs "26.1")) :commit "45f3769350725ab2031c67871400139f3806bb36" :authors '(("Amy Grinn" . "grinn.amy@gmail.com")) :maintainer '("Amy Grinn" . "grinn.amy@gmail.com") :keywords '("tools") :url "https://gitlab.com/grinn.amy/boxy")
